@@ -1,3 +1,10 @@
+var assetUrl = __admin_media_prefix__.substring(0, __admin_media_prefix__.lastIndexOf('/'))
+
+if( ! jQuery.widget) $.getScript(assetUrl + '/jquery.ui.widget.js')
+if( ! $.ajaxTransport) $.getScript(assetUrl + '/jquery.iframe-transport.js')
+if( ! jQuery().fileupload) $.getScript(assetUrl + '/jquery.fileupload.js')
+
+
 $(function(){
 
   var attach = function($fileInput, policy_url, el){
